@@ -1,4 +1,4 @@
-from random import choice
+import random
 import requests
 import time
 from requests.adapters import HTTPAdapter
@@ -18,13 +18,14 @@ class get_helper:
 
     def run(self, url, cookie=None, method='GET', data=None):
         headers = self.app.config['get']['headers']
-        headers['user-agent'] = choice(self.app.ua_list)
+        headers['user-agent'] = random.choice(self.app.ua_list)
         proxy = None
         proxies = None
         if self.app.config['proxy']['enable_proxy']:
+            random.shuffle(self.proxies_list)
             for i in range(len(self.proxies_list)):
-                if self.proxies_list[i] not in self.app.using_proxies:
-                    proxy = self.proxies_list[i]
+                proxy = random.choice(self.proxies_list)
+                if proxy not in self.app.using_proxies:
                     self.app.using_proxies.append(proxy)
                     break
             if self.app.config['proxy']['proxy_autentification']:
